### Setup completed!

CherryMusic is saving the configuration and preparing the first start.

# CherryMusic Setup

Basic Setup
Media base directory

The absolute path where your music is located. ?

### Media base directory

On Linux this could be

    /home/$USER/Music

On Windows it could be

    C:\Documents and Settings\[user name]\My Documents\My Music

On Mac it could be

    /Users/username/Music/

Use a file browser to find the exact path and copy it here.

Server Port

This specifies the port on which CherryMusic will listen ?

### Server Port

The server port specifies how to reach CherryMusic.
(a number between 1 and 65535)

You can reach CherryMusic then by typing in the `IP:PORT` address in the browser. For example, if the Port you chose is `8080` and your machine has the IP `192.168.0.10`, you will have to write `192.168.0.10:8080` in your browser. You will need to pick a port above 1024 to run CherryMusic as non-super-user.

Security
Permit remote admin login
Permit for admin users to log on from other machines in the network ?

### Automatic login on localhost

When remote admin login is disabled, admin users may only log in from the computer cherrymusic is currently running on. This can improve security.

Automatic login on localhost
Automatic login when accessing CherryMusic from the same computer it is running on. ?

### Automatic login on localhost

Normally, you will only login once; Your session will stay for a while. This feature is therefore especially useful for people that automatically delete their cookies when they close their browser. If you're one of them, this option will save you 2 seconds per day.

Localhost only
This will disable any access from remote computers to CherryMusic. ?

### Localhost only

Normally you want to keep this unchecked. When enabled, you won't be able to access CherryMusic with any other device, neither in the local network nor from the internet. It is only useful for paranoid people using CherryMusic as their preferred local music player.

Extras
Fetch Album Cover Art from Web
Automatic fetch album cover art from the web ?

### Automatic login on localhost

Tries to fetch the album cover from various locations in the web, if no image is found locally. By default it will be fetched from amazon. They will be shown next to folders that qualify as an album.

On-the-fly transcoding
Automatically convert music while streaming for better compability ?

### On-the-fly transcoding

Since not all browsers have the same playback capabilities or some files are not suitable for streaming, this feature allows the server to transcode (convert) the music into another format before being send to the client. If the machine you are using as server isn't from the '80s, therefore a slow machine, you should enable this feature to support as many playback devices/browser as possible.

System capabilities ?

### System capabilities

The installed label shows which optional programs have been installed and which feature was therefore enabled. All programs that show not installed, don't need to be installed for CherryMusic to work, but each of them adds extra functionality, you might miss otherwise. The grey not installed labels show you, that a certain program has not been installed, but it wouldn't lead to any additional features if you did, since other programs already took their job.